# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.0a1

([Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/v0.3.0a0...b4010718a650269dc99d37c2248aedc203d40bc8))

### Enhancements made

- Support for voila v0.3 [#156](https://github.com/voila-dashboards/voila-gridstack/pull/156) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voila-gridstack/graphs/contributors?from=2021-11-03&to=2021-12-28&type=c))

[@hbcarlos](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoila-gridstack+involves%3Ahbcarlos+updated%3A2021-11-03..2021-12-28&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## [0.3.0a0](https://github.com/voila-dashboards/voila-gridstack/tree/v0.3.0a0) (2021-10-03)

([Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.2.0...cda2348b88a7c664e2e69042bbb26d16e2e1ec02))

### Enhancements made

- Solves fixed layout on the template [#140](https://github.com/voila-dashboards/voila-gridstack/pull/140) ([@hbcarlos](https://github.com/hbcarlos))
- Update to JupyterLab v3.1 and support RTC [#142](https://github.com/voila-dashboards/voila-gridstack/pull/142) ([@hbcarlos](https://github.com/hbcarlos))
- Pin button in gridstack items [#116](https://github.com/voila-dashboards/voila-gridstack/pull/116) ([@hbcarlos](https://github.com/hbcarlos))

### Bugs fixed

- Small clean up and solves #150 [#151](https://github.com/voila-dashboards/voila-gridstack/pull/151) ([@hbcarlos](https://github.com/hbcarlos))

### Maintenance and upkeep improvements

- Rename master to main [#152](https://github.com/voila-dashboards/voila-gridstack/pull/152) ([@jtpio](https://github.com/jtpio))
- Add releaser config [#148](https://github.com/voila-dashboards/voila-gridstack/pull/148) ([@jtpio](https://github.com/jtpio))
- Update to jupyter-packaging v0.10 [#145](https://github.com/voila-dashboards/voila-gridstack/pull/145) ([@hbcarlos](https://github.com/hbcarlos))
- Update the Binder URL for the Voila badge [#125](https://github.com/voila-dashboards/voila-gridstack/pull/125) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Bump tar from 4.4.13 to 4.4.15 [#141](https://github.com/voila-dashboards/voila-gridstack/pull/141) ([@dependabot](https://github.com/dependabot))
- Bump postcss from 7.0.35 to 7.0.36 [#136](https://github.com/voila-dashboards/voila-gridstack/pull/136) ([@dependabot](https://github.com/dependabot))
- Bump ws from 7.4.1 to 7.4.6 [#135](https://github.com/voila-dashboards/voila-gridstack/pull/135) ([@dependabot](https://github.com/dependabot))
- Bump browserslist from 4.16.0 to 4.16.6 [#134](https://github.com/voila-dashboards/voila-gridstack/pull/134) ([@dependabot](https://github.com/dependabot))
- Bump lodash from 4.17.20 to 4.17.21 [#133](https://github.com/voila-dashboards/voila-gridstack/pull/133) ([@dependabot](https://github.com/dependabot))
- Bump hosted-git-info from 2.8.8 to 2.8.9 [#131](https://github.com/voila-dashboards/voila-gridstack/pull/131) ([@dependabot](https://github.com/dependabot))
- Bump handlebars from 4.7.6 to 4.7.7 [#130](https://github.com/voila-dashboards/voila-gridstack/pull/130) ([@dependabot](https://github.com/dependabot))
- Bump underscore from 1.12.0 to 1.13.1 [#129](https://github.com/voila-dashboards/voila-gridstack/pull/129) ([@dependabot](https://github.com/dependabot))
- Bump ssri from 6.0.1 to 6.0.2 [#127](https://github.com/voila-dashboards/voila-gridstack/pull/127) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voila-gridstack/graphs/contributors?from=2021-04-09&to=2021-11-03&type=c))

[@dependabot](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoila-gridstack+involves%3Adependabot+updated%3A2021-04-09..2021-11-02&type=Issues) | [@hbcarlos](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoila-gridstack+involves%3Ahbcarlos+updated%3A2021-04-09..2021-11-02&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoila-gridstack+involves%3Ajtpio+updated%3A2021-04-09..2021-11-02&type=Issues)

## [0.2.0](https://github.com/voila-dashboards/voila-gridstack/tree/0.2.0) (2021-04-09)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.1.0...0.2.0)

**Closed issues:**

- Drag and drop not working [\#122](https://github.com/voila-dashboards/voila-gridstack/issues/122)
- Fix dependencies [\#111](https://github.com/voila-dashboards/voila-gridstack/issues/111)
- Add tooltip when drag in is forbidden [\#108](https://github.com/voila-dashboards/voila-gridstack/issues/108)
- Update open editor icon [\#98](https://github.com/voila-dashboards/voila-gridstack/issues/98)
- Update Gridstack to v4.0.1 [\#97](https://github.com/voila-dashboards/voila-gridstack/issues/97)
- Explicit open will occur in new window [\#95](https://github.com/voila-dashboards/voila-gridstack/issues/95)
- Open editor with split-right [\#93](https://github.com/voila-dashboards/voila-gridstack/issues/93)
- Use a closer approach to clone output view [\#92](https://github.com/voila-dashboards/voila-gridstack/issues/92)
- Display the grid [\#89](https://github.com/voila-dashboards/voila-gridstack/issues/89)
- Drag&Drop improvements [\#87](https://github.com/voila-dashboards/voila-gridstack/issues/87)
- Cell toolbar is not sticky [\#86](https://github.com/voila-dashboards/voila-gridstack/issues/86)
- Similar notebook toolbar buttons for Voila [\#84](https://github.com/voila-dashboards/voila-gridstack/issues/84)
- JupyterLab 3 on Binder [\#79](https://github.com/voila-dashboards/voila-gridstack/issues/79)
- When opening a second editor focuses the first one [\#77](https://github.com/voila-dashboards/voila-gridstack/issues/77)
- Release @voila-dashboards/jupyterlab-gridstack [\#72](https://github.com/voila-dashboards/voila-gridstack/issues/72)

**Merged pull requests:**

- Update release instructions [\#121](https://github.com/voila-dashboards/voila-gridstack/pull/121) ([jtpio](https://github.com/jtpio))
- Use a version range for gridstack [\#120](https://github.com/voila-dashboards/voila-gridstack/pull/120) ([fcollonval](https://github.com/fcollonval))
- Add tooltip when drag in is forbidden [\#118](https://github.com/voila-dashboards/voila-gridstack/pull/118) ([fcollonval](https://github.com/fcollonval))
- Style improvements [\#115](https://github.com/voila-dashboards/voila-gridstack/pull/115) ([hbcarlos](https://github.com/hbcarlos))
- Change launch button [\#114](https://github.com/voila-dashboards/voila-gridstack/pull/114) ([hbcarlos](https://github.com/hbcarlos))
- Update minimal version of dependencies [\#112](https://github.com/voila-dashboards/voila-gridstack/pull/112) ([fcollonval](https://github.com/fcollonval))
- Bump to gridstack 4.0.1 and drop jq [\#107](https://github.com/voila-dashboards/voila-gridstack/pull/107) ([fcollonval](https://github.com/fcollonval))
- Add revert button [\#106](https://github.com/voila-dashboards/voila-gridstack/pull/106) ([fcollonval](https://github.com/fcollonval))
- Display shadow element when dragging from notebook [\#105](https://github.com/voila-dashboards/voila-gridstack/pull/105) ([fcollonval](https://github.com/fcollonval))
- Update cursor on grid widget toolbar [\#104](https://github.com/voila-dashboards/voila-gridstack/pull/104) ([fcollonval](https://github.com/fcollonval))
- Improve template for inheritance [\#103](https://github.com/voila-dashboards/voila-gridstack/pull/103) ([fcollonval](https://github.com/fcollonval))
- Improve drag & drop from notebook [\#100](https://github.com/voila-dashboards/voila-gridstack/pull/100) ([fcollonval](https://github.com/fcollonval))
- Add dashboard icon [\#99](https://github.com/voila-dashboards/voila-gridstack/pull/99) ([fcollonval](https://github.com/fcollonval))
- Use same wording as voila preview for button tooltip [\#96](https://github.com/voila-dashboards/voila-gridstack/pull/96) ([fcollonval](https://github.com/fcollonval))
- Open editor in split right panel [\#94](https://github.com/voila-dashboards/voila-gridstack/pull/94) ([fcollonval](https://github.com/fcollonval))
- Display background grid [\#91](https://github.com/voila-dashboards/voila-gridstack/pull/91) ([fcollonval](https://github.com/fcollonval))
- Fix focus on wrong editor [\#90](https://github.com/voila-dashboards/voila-gridstack/pull/90) ([fcollonval](https://github.com/fcollonval))
- Make cell toolbar sticky [\#88](https://github.com/voila-dashboards/voila-gridstack/pull/88) ([fcollonval](https://github.com/fcollonval))
- Update CHANGELOG.md [\#83](https://github.com/voila-dashboards/voila-gridstack/pull/83) ([jtpio](https://github.com/jtpio))
- Update table header in README.md [\#82](https://github.com/voila-dashboards/voila-gridstack/pull/82) ([jtpio](https://github.com/jtpio))
- Update environment.yml [\#81](https://github.com/voila-dashboards/voila-gridstack/pull/81) ([hbcarlos](https://github.com/hbcarlos))
- Fix typo in README.md [\#80](https://github.com/voila-dashboards/voila-gridstack/pull/80) ([jtpio](https://github.com/jtpio))
- Update Readme [\#78](https://github.com/voila-dashboards/voila-gridstack/pull/78) ([hbcarlos](https://github.com/hbcarlos))

## [0.1.0](https://github.com/voila-dashboards/voila-gridstack/tree/0.1.0) (2021-01-07)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.1.0rc0...0.1.0)

**Merged pull requests:**

- Add CHANGELOG.md [\#76](https://github.com/voila-dashboards/voila-gridstack/pull/76) ([jtpio](https://github.com/jtpio))

## [0.1.0rc0](https://github.com/voila-dashboards/voila-gridstack/tree/0.1.0rc0) (2021-01-06)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.12...0.1.0rc0)

**Closed issues:**

- Update the tests to work with the latest jupyter server [\#70](https://github.com/voila-dashboards/voila-gridstack/issues/70)

**Merged pull requests:**

- Add extra dependencies to the release instructions [\#75](https://github.com/voila-dashboards/voila-gridstack/pull/75) ([jtpio](https://github.com/jtpio))
- Add base_url fixture for the tests [\#74](https://github.com/voila-dashboards/voila-gridstack/pull/74) ([jtpio](https://github.com/jtpio))
- Update gridstack 3.1 [\#73](https://github.com/voila-dashboards/voila-gridstack/pull/73) ([hbcarlos](https://github.com/hbcarlos))
- Add Jupyterlab GridStack [\#69](https://github.com/voila-dashboards/voila-gridstack/pull/69) ([jtpio](https://github.com/jtpio))

## [0.0.12](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.12) (2020-12-03)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.11...0.0.12)

**Closed issues:**

- \[classic notebook editor\] The classic layout editor un-hides hidden cells [\#63](https://github.com/voila-dashboards/voila-gridstack/issues/63)

**Merged pull requests:**

- Add RELEASE.md with release instructions [\#68](https://github.com/voila-dashboards/voila-gridstack/pull/68) ([jtpio](https://github.com/jtpio))
- Handle gridstack events [\#67](https://github.com/voila-dashboards/voila-gridstack/pull/67) ([jtpio](https://github.com/jtpio))
- Fixes for the classic notebook editor [\#65](https://github.com/voila-dashboards/voila-gridstack/pull/65) ([jtpio](https://github.com/jtpio))
- Fix usage of action name in nb extension [\#64](https://github.com/voila-dashboards/voila-gridstack/pull/64) ([jtpio](https://github.com/jtpio))

## [0.0.11](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.11) (2020-09-21)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.10...0.0.11)

**Closed issues:**

- Replace the matplotlib radar with a bqplot figure [\#61](https://github.com/voila-dashboards/voila-gridstack/issues/61)
- 'contents_manager' trait error with voila as a server extension [\#58](https://github.com/voila-dashboards/voila-gridstack/issues/58)
- Example dashboard does not render on Firefox [\#55](https://github.com/voila-dashboards/voila-gridstack/issues/55)
- Update to gridstack 2.0.0 [\#48](https://github.com/voila-dashboards/voila-gridstack/issues/48)

**Merged pull requests:**

- Replaced radar with lines in scotch dashboard [\#62](https://github.com/voila-dashboards/voila-gridstack/pull/62) ([JohanMabille](https://github.com/JohanMabille))
- Upgrade to gridstack 2.0 [\#56](https://github.com/voila-dashboards/voila-gridstack/pull/56) ([jtpio](https://github.com/jtpio))

## [0.0.10](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.10) (2020-09-17)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.1.0a7...0.0.10)

**Merged pull requests:**

- Add gridstack to metadata [\#60](https://github.com/voila-dashboards/voila-gridstack/pull/60) ([SylvainCorlay](https://github.com/SylvainCorlay))
- Require voila final [\#59](https://github.com/voila-dashboards/voila-gridstack/pull/59) ([SylvainCorlay](https://github.com/SylvainCorlay))
- Update to voila 0.2.0b1 [\#57](https://github.com/voila-dashboards/voila-gridstack/pull/57) ([SylvainCorlay](https://github.com/SylvainCorlay))

## [0.1.0a7](https://github.com/voila-dashboards/voila-gridstack/tree/0.1.0a7) (2020-09-09)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.1.0a6...0.1.0a7)

**Closed issues:**

- Add instructions for a dev setup [\#49](https://github.com/voila-dashboards/voila-gridstack/issues/49)
- ValueError: No template sub-directory with name 'gridstack' found in the following paths: [\#47](https://github.com/voila-dashboards/voila-gridstack/issues/47)

**Merged pull requests:**

- Update config if show_handles is defined [\#54](https://github.com/voila-dashboards/voila-gridstack/pull/54) ([jtpio](https://github.com/jtpio))
- Update the server extension to the refactored template system [\#53](https://github.com/voila-dashboards/voila-gridstack/pull/53) ([jtpio](https://github.com/jtpio))
- Add a Development section to the README [\#52](https://github.com/voila-dashboards/voila-gridstack/pull/52) ([jtpio](https://github.com/jtpio))

## [0.1.0a6](https://github.com/voila-dashboards/voila-gridstack/tree/0.1.0a6) (2020-09-08)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.1.0a5...0.1.0a6)

**Closed issues:**

- Notebook fix [\#40](https://github.com/voila-dashboards/voila-gridstack/issues/40)
- `voila notebook.ipynb --template=gridstack` no longer interactive? [\#29](https://github.com/voila-dashboards/voila-gridstack/issues/29)

**Merged pull requests:**

- Use voila beta0 [\#51](https://github.com/voila-dashboards/voila-gridstack/pull/51) ([SylvainCorlay](https://github.com/SylvainCorlay))
- Use environment.yml and stable releases on Binder [\#50](https://github.com/voila-dashboards/voila-gridstack/pull/50) ([jtpio](https://github.com/jtpio))

## [0.1.0a5](https://github.com/voila-dashboards/voila-gridstack/tree/0.1.0a5) (2020-08-19)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.1.0a2...0.1.0a5)

**Merged pull requests:**

- fix: visibility hidden blocked mouse, causing some handles not to work [\#45](https://github.com/voila-dashboards/voila-gridstack/pull/45) ([maartenbreddels](https://github.com/maartenbreddels))

## [0.1.0a2](https://github.com/voila-dashboards/voila-gridstack/tree/0.1.0a2) (2020-08-18)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.9...0.1.0a2)

**Merged pull requests:**

- Replace Default Handle Icons [\#44](https://github.com/voila-dashboards/voila-gridstack/pull/44) ([madhur-tandon](https://github.com/madhur-tandon))
- Fix overlap for Drag Handle [\#43](https://github.com/voila-dashboards/voila-gridstack/pull/43) ([madhur-tandon](https://github.com/madhur-tandon))
- Fix CSS to make UI more appealing [\#42](https://github.com/voila-dashboards/voila-gridstack/pull/42) ([madhur-tandon](https://github.com/madhur-tandon))
- Refactor template take3 [\#41](https://github.com/voila-dashboards/voila-gridstack/pull/41) ([maartenbreddels](https://github.com/maartenbreddels))

## [0.0.9](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.9) (2020-06-05)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.8...0.0.9)

**Closed issues:**

- Grid persistence [\#34](https://github.com/voila-dashboards/voila-gridstack/issues/34)
- New release? [\#32](https://github.com/voila-dashboards/voila-gridstack/issues/32)
- Not able to scroll down when the content overflows [\#31](https://github.com/voila-dashboards/voila-gridstack/issues/31)

**Merged pull requests:**

- jupyter extension for grid persistence [\#38](https://github.com/voila-dashboards/voila-gridstack/pull/38) ([brichet](https://github.com/brichet))
- feat: make inspection of the config possible [\#37](https://github.com/voila-dashboards/voila-gridstack/pull/37) ([mariobuikhuizen](https://github.com/mariobuikhuizen))
- Fix \#31 : add scroll when body overflows [\#33](https://github.com/voila-dashboards/voila-gridstack/pull/33) ([brichet](https://github.com/brichet))

## [0.0.8](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.8) (2020-01-08)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.7...0.0.8)

**Closed issues:**

- gridstack not working anymore? [\#27](https://github.com/voila-dashboards/voila-gridstack/issues/27)
- README documentation error [\#24](https://github.com/voila-dashboards/voila-gridstack/issues/24)

**Merged pull requests:**

- Load gridstack from jsdelivr [\#28](https://github.com/voila-dashboards/voila-gridstack/pull/28) ([cnydw](https://github.com/cnydw))

## [0.0.7](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.7) (2019-11-10)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.6...0.0.7)

**Closed issues:**

- new behavior with voila \> 0.1.14 [\#20](https://github.com/voila-dashboards/voila-gridstack/issues/20)
- gridstack templates don't work when installed with setup.py [\#15](https://github.com/voila-dashboards/voila-gridstack/issues/15)
- AttributeError: 'VoilaHandler' object has no attribute 'exporter' [\#12](https://github.com/voila-dashboards/voila-gridstack/issues/12)
- Styling gridstack template [\#11](https://github.com/voila-dashboards/voila-gridstack/issues/11)
- using gridstack template on MyBinder hosted Voila dashboard [\#10](https://github.com/voila-dashboards/voila-gridstack/issues/10)
- Output is different on Firefox and Chrome [\#9](https://github.com/voila-dashboards/voila-gridstack/issues/9)
- \[DISCUSS\] Grid Layout Persistence [\#8](https://github.com/voila-dashboards/voila-gridstack/issues/8)

**Merged pull requests:**

- Update to voila 0.1.18 [\#25](https://github.com/voila-dashboards/voila-gridstack/pull/25) ([SylvainCorlay](https://github.com/SylvainCorlay))
- Remove markdown anchors [\#23](https://github.com/voila-dashboards/voila-gridstack/pull/23) ([SylvainCorlay](https://github.com/SylvainCorlay))
- Binder build [\#22](https://github.com/voila-dashboards/voila-gridstack/pull/22) ([btel](https://github.com/btel))
- add html5 validator to workflows [\#19](https://github.com/voila-dashboards/voila-gridstack/pull/19) ([btel](https://github.com/btel))
- trigger github CI on pull request [\#18](https://github.com/voila-dashboards/voila-gridstack/pull/18) ([btel](https://github.com/btel))
- WIP: migrate to jupyter_dashboard spec [\#17](https://github.com/voila-dashboards/voila-gridstack/pull/17) ([btel](https://github.com/btel))
- adding first tests + CI [\#16](https://github.com/voila-dashboards/voila-gridstack/pull/16) ([btel](https://github.com/btel))
- Fix link to voila repo [\#14](https://github.com/voila-dashboards/voila-gridstack/pull/14) ([btel](https://github.com/btel))
- Update URLs [\#13](https://github.com/voila-dashboards/voila-gridstack/pull/13) ([SylvainCorlay](https://github.com/SylvainCorlay))
- Document installation with conda [\#7](https://github.com/voila-dashboards/voila-gridstack/pull/7) ([mkcor](https://github.com/mkcor))

## [0.0.6](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.6) (2019-07-06)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.5...0.0.6)

**Merged pull requests:**

- Update to voila 0.1.6 [\#6](https://github.com/voila-dashboards/voila-gridstack/pull/6) ([SylvainCorlay](https://github.com/SylvainCorlay))

## [0.0.5](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.5) (2019-07-06)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.1...0.0.5)

**Closed issues:**

- Stopped working with latest version of voila [\#4](https://github.com/voila-dashboards/voila-gridstack/issues/4)

**Merged pull requests:**

- Fix gridstack template [\#5](https://github.com/voila-dashboards/voila-gridstack/pull/5) ([SylvainCorlay](https://github.com/SylvainCorlay))

## [0.0.1](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.1) (2019-06-18)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.3...0.0.1)

**Closed issues:**

- The source package on PyPI doesn't contain the license in v0.0.3 [\#1](https://github.com/voila-dashboards/voila-gridstack/issues/1)

**Merged pull requests:**

- Add license file [\#2](https://github.com/voila-dashboards/voila-gridstack/pull/2) ([SylvainCorlay](https://github.com/SylvainCorlay))

## [0.0.3](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.3) (2019-06-11)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/0.0.2...0.0.3)

## [0.0.2](https://github.com/voila-dashboards/voila-gridstack/tree/0.0.2) (2019-06-07)

[Full Changelog](https://github.com/voila-dashboards/voila-gridstack/compare/428adafd2d2eecade1950bee35d4762d21f8b738...0.0.2)

\* _This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)_
